@@ -8,7 +8,7 @@ from json import dumps as json_dump, loads as json_load
 import argparse
 from config import __version__
 
-global_template = None
+global_template: dict | None = None
 
 # TODO: добавить типы переменных
 
@@ -26,16 +26,22 @@ def __wait_confirmation__(message: str) -> bool:
     return True
 
 
+def __walk_on_json_path__(path: str, element: dict, root_element: dict) -> dict:
+    path = path.split("/")
+    link_element = element
+    for i in path:
+        match i:
+            case "#":
+                link_element = root_element
+            case _:
+                link_element = link_element[i]
+    return link_element
+
+
 def __parse_template__(element):
     global global_template
     if element.get("$ref"):
-        path = element["$ref"].split("/")
-        link_element = element
-        for i in path:
-            match i:
-                case "#": link_element = global_template
-                case _: link_element = link_element[i]
-        element = link_element
+        element = __walk_on_json_path__(element["$ref"], element, global_template)
     if element["type"] == "object":
         config = {}
         for i in element["required"]:
@@ -53,7 +59,7 @@ def create_command(params):
     with open(params.template_config) as template_file:
         template = json_load(template_file.read())
 
-    if path_exists(params.config_file) and \
+    if not params.force and path_exists(params.config_file) and \
             not __wait_confirmation__('Файл конфигурации уже существует, перезаписать его?'):
         return
 
@@ -61,6 +67,14 @@ def create_command(params):
     global_template = template
     config = __parse_template__(template)
 
+    print(f"{config=}")
+    if params.extra_vars:
+        for i in params.extra_vars:
+            path, value = i.split("=")
+            path = path.split('/')
+            element = __walk_on_json_path__("/".join(path[:-1]), config, config)
+            element[path[-1]] = value
+
     __dump_json__(params.config_file, config)
     print('Конфигурация создана')
 
@@ -144,6 +158,8 @@ def create_parse():
     create_command_parser = subparsers.add_parser("create", add_help=False)
     create_command_parser.add_argument('config_file')
     create_command_parser.add_argument("template_config")
+    create_command_parser.add_argument("-f", "--force", action="store_true", default=False)
+    create_command_parser.add_argument("-e", "--extra-vars", nargs='+')
     # endregion
 
     # region merge template
